import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DeleteEventRuleRequest, DeleteEventRuleResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteEventRuleCommand}.
 */
export interface DeleteEventRuleCommandInput extends DeleteEventRuleRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteEventRuleCommand}.
 */
export interface DeleteEventRuleCommandOutput extends DeleteEventRuleResponse, __MetadataBearer {
}
declare const DeleteEventRuleCommand_base: {
    new (input: DeleteEventRuleCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteEventRuleCommandInput, DeleteEventRuleCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteEventRuleCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteEventRuleCommandInput, DeleteEventRuleCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes an EventRule.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, DeleteEventRuleCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, DeleteEventRuleCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // DeleteEventRuleRequest
 *   arn: "STRING_VALUE", // required
 * };
 * const command = new DeleteEventRuleCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteEventRuleCommandInput - {@link DeleteEventRuleCommandInput}
 * @returns {@link DeleteEventRuleCommandOutput}
 * @see {@link DeleteEventRuleCommandInput} for command's `input` shape.
 * @see {@link DeleteEventRuleCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Updating or deleting a resource can cause an inconsistent state.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Request references a resource which does not exist. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class DeleteEventRuleCommand extends DeleteEventRuleCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteEventRuleRequest;
            output: {};
        };
        sdk: {
            input: DeleteEventRuleCommandInput;
            output: DeleteEventRuleCommandOutput;
        };
    };
}
